##  Deleting a Relation
If a relation becomes obsolete, you can delete it. To do that, select a relation, click Delete on the right-side panel, confirm your action, then save the changes.
**Caution**
When you delete a relation, this also removes all associated data from both sides of the relation. This action is irreversible. To prevent any potential disruptions or negative experiences for workspace users, consider deleting relations outside of regular business hours.
The following relations cannot be deleted:
  * The relation includes all fact sheet types as its target, such as in a parent-child relation.
  * The relation is a constraining relation or is constrained by another relation.
  * The relation is part of a naming rule for a fact sheet type. Naming rules, which may be predefined in the meta model configuration, define how the display name of a fact sheet is formed.
